@@ -27,9 +27,12 @@ class Session(object):
         else:
             self.base64string = None
 
-    def fetch(self, url, method='GET', **kwargs):
+    def fetch(self, url, method='GET', body=None, **kwargs):
         opener = urllib2.build_opener(urllib2.HTTPSHandler)
-        request = urllib2.Request(url)
+        if method == 'PUT' or method == 'POST':
+            request = urllib2.Request(url, data=body)
+        else:
+            request = urllib2.Request(url)
         request.add_header('Content-Type', 'application/json')
         if self.base64string is not None:
             request.add_header("Authorization", "Basic %s" % self.base64string)
