@@ -1,6 +1,6 @@
 __author__ = 'mkoponen'
 
-from finch.errors import HTTPError
+from finch_urllib2.errors import HTTPError
 
 # Intrazon-specific errors start from 1000 up. Otherwise they are HTTP error codes, except for special case 599 which
 # means timeout
