@@ -15,6 +15,9 @@ class Application(Model):
     def decode(self, response):
         return parse_application(json.loads(response.body))
 
+    def encode(self):
+        return json.dumps(dict(self)), 'application/json'
+
     def __repr__(self):
         return 'Application({}/{})'.format(self.key, self.name)
 
@@ -39,6 +42,9 @@ class VirtualGood(Model):
     def decode(self, response):
         return parse_virtual_good(json.loads(response.body))
 
+    def encode(self):
+        return json.dumps(dict(self)), 'application/json'
+
     def __repr__(self):
         return 'VirtualGood({}/{})'.format(self.key, self.name)
 
@@ -82,6 +88,9 @@ class VirtualGoodPurchase(Model):
     def decode(self, response):
         return parse_virtual_good_purchase(json.loads(response.body))
 
+    def encode(self):
+        return json.dumps(dict(self)), 'application/json'
+
     def __repr__(self):
         return 'VirtualGoodPurchase({}/{})'.format(self.virtual_good_key, self.player_key)
 
@@ -126,6 +135,9 @@ class Player(Model):
     def decode(self, response):
         return parse_player(json.loads(response.body))
 
+    def encode(self):
+        return json.dumps(dict(self)), 'application/json'
+
     def __repr__(self):
         return 'Player({}/{})'.format(self.key, self.name)
 
@@ -171,6 +183,9 @@ class PaymentMethod(Model):
     def decode(self, response):
         return parse_payment_method(json.loads(response.body))
 
+    def encode(self):
+        return json.dumps(dict(self)), 'application/json'
+
     def __repr__(self):
         return 'PaymentMethod({}/{})'.format(self.cc_num, self.cc_name)
 
@@ -224,16 +239,16 @@ class IntraZon(object):
         new_player.last_login = last_login
         new_player.app_unique_id = app_unique_id
         players = Players(self.application_key, self.session)
-        players.add(new_player, self.__on_player_add)
+        return self.__on_player_add(players.add(new_player))
 
-    def purchase_virtual_good(self, callback, player_key, virtual_good_key):
+    def purchase_virtual_good(self, player_key, virtual_good_key):
         new_virtual_good_purchase = VirtualGoodPurchase(player_key, virtual_good_key)
         new_virtual_good_purchase.currency = "usd"
         new_virtual_good_purchase.amount = 1
         virtual_good_purchases = VirtualGoodPurchases(player_key, virtual_good_key, self.session)
-        virtual_good_purchases.add(new_virtual_good_purchase, self.__on_virtual_good_purchase)
+        return self.__on_virtual_good_purchase(virtual_good_purchases.add(new_virtual_good_purchase))
 
-    def register_payment_method(self, callback, player_key, cc_num, cc_csc, cc_name, cc_exp_month, cc_exp_year):
+    def register_payment_method(self, player_key, cc_num, cc_csc, cc_name, cc_exp_month, cc_exp_year):
         new_payment = PaymentMethod(player_key)
         new_payment.cc_num = cc_num
         new_payment.cc_csc = cc_csc
@@ -241,7 +256,7 @@ class IntraZon(object):
         new_payment.cc_exp_month = cc_exp_month
         new_payment.cc_exp_year = cc_exp_year
         payment_methods = PaymentMethods(player_key, self.session)
-        payment_methods.add(new_payment, self.__on_payment_method_add)
+        return self.__on_payment_method_add(payment_methods.add(new_payment))
 
     def __on_virtual_goods(self, tuple):
         virtual_goods=tuple[0]
@@ -256,35 +271,41 @@ class IntraZon(object):
         else:
             return (virtual_goods, None)
 
-    def __on_player_add(self, player, error):
+    def __on_player_add(self, tuple):
+        player=tuple[0]
+        error=tuple[1]
         if error:
             if hasattr(error, "code"):
                 iz_error = IntraZonError(error.code)
             else:
                 print "Other exception: %s" % error.message
                 iz_error = IntraZonError(1000)
-            self.callback(None, iz_error)
+            return (None, iz_error)
         else:
-            self.callback(player, None)
+            return (player, None)
 
-    def __on_payment_method_add(self, payment_method, error):
+    def __on_payment_method_add(self, tuple):
+        payment_method=tuple[0]
+        error=tuple[1]
         if error:
             if hasattr(error, "code"):
                 iz_error = IntraZonError(error.code)
             else:
                 print "Other exception: %s" % error.message
                 iz_error = IntraZonError(1000)
-            self.callback(None, iz_error)
+            return (None, iz_error)
         else:
-            self.callback(payment_method, None)
+            return (payment_method, None)
 
-    def __on_virtual_good_purchase(self, virtual_good_purchase, error):
+    def __on_virtual_good_purchase(self, tuple):
+        virtual_good_purchase=tuple[0]
+        error=tuple[1]
         if error:
             if hasattr(error, "code"):
                 iz_error = IntraZonError(error.code)
             else:
                 print "Other exception: %s" % error.message
                 iz_error = IntraZonError(1000)
-            self.callback(None, iz_error)
+            return (None, iz_error)
         else:
-            self.callback(virtual_good_purchase, None)
+            return (virtual_good_purchase, None)
